searchData={"items":[{"type":"module","title":"FLAMEK8sBackend","doc":"Kubernetes Backend implementation.\n\n#","ref":"FLAMEK8sBackend.html"},{"type":"module","title":"Usage - FLAMEK8sBackend","doc":"Configure the flame backend in our configuration.\n\n```\n# config.exs\nif config_env() == :prod do\n  config :flame, :backend, FLAMEK8sBackend\n  config :flame, FLAMEK8sBackend, log: :debug\nend\n```\n\n### Options\n\nThe following backend options are supported:\n\n  * `container_name` - If your application pod runs multiple containers\n    (initContainers excluded), use this option to pass the name of the\n    container running this application. If not given, the first container\n    in the list of containers is used to lookup env vars and resources to\n    be used for the runner pods.\n\n  * `:log` - The log level to use for verbose logging. Defaults to `false`.\n\n  * `:token_path` - Path to the service account token. Defaults to\n    `\"/var/run/secrets/kubernetes.io/serviceaccount\"`\n\n#","ref":"FLAMEK8sBackend.html#module-usage"},{"type":"module","title":"Prerequisites - FLAMEK8sBackend","doc":"In order for this to work, your application needs to meet some requirements.\n\n##","ref":"FLAMEK8sBackend.html#module-prerequisites"},{"type":"module","title":"Env Variables - FLAMEK8sBackend","doc":"In order for the backend to be able to get informations from your pod and use\nthem for  the runner pods (e.g. env variables), you have to define `POD_NAME`\nand `POD_NAMESPACE` environment variables on your pod.\n\n```yaml\napiVersion: apps/v1\nkind: Deployment\nspec:\nselector:\n  matchLabels:\n    app: myapp\ntemplate:\n  spec:\n    containers:\n      - env:\n          - name: POD_NAME\n            valueFrom:\n              fieldRef:\n                apiVersion: v1\n                fieldPath: metadata.name\n          - name: POD_NAMESPACE\n            valueFrom:\n              fieldRef:\n                apiVersion: v1\n                fieldPath: metadata.namespace\n```\n\n##","ref":"FLAMEK8sBackend.html#module-env-variables"},{"type":"module","title":"RBAC - FLAMEK8sBackend","doc":"Your application needs run as a service account with permissions to manage\npods. This is a simple\n\n```yaml\n---\napiVersion: v1\nkind: ServiceAccount\nmetadata:\nname: myapp\nnamespace: app-namespace\n---\napiVersion: rbac.authorization.k8s.io/v1\nkind: Role\nmetadata:\nnamespace: app-namespace\nname: pod-mgr\nrules:\n- apiGroups: [\"\"]\n  resources: [\"pods\"]\n  verbs: [\"create\", \"get\", \"list\", \"delete\", \"patch\"]\n---\napiVersion: rbac.authorization.k8s.io/v1\nkind: RoleBinding\nmetadata:\nname: myapp-pod-mgr\nnamespace: app-namespace\nsubjects:\n- kind: ServiceAccount\n  name: myapp\n  namespace: app-namespace\nroleRef:\nkind: Role\nname: pod-mgr\napiGroup: rbac.authorization.k8s.io\n---\napiVersion: apps/v1\nkind: Deployment\nspec:\ntemplate:\n  spec:\n    serviceAccountName: my-app\n```\n\n##","ref":"FLAMEK8sBackend.html#module-rbac"},{"type":"module","title":"Clustering - FLAMEK8sBackend","doc":"Your application needs to be able to form a cluster with your runners. Define\n`POD_IP`, `RELEASE_DISTRIBUTION` and `RELEASE_NODE` environment variables on\nyour pods as follows:\n\n```yaml\napiVersion: apps/v1\nkind: Deployment\nspec:\ntemplate:\n  spec:\n    containers:\n      - env:\n          - name: POD_IP\n            valueFrom:\n              fieldRef:\n                apiVersion: v1\n                fieldPath: status.podIP\n          - name: RELEASE_DISTRIBUTION\n            value: name\n          - name: RELEASE_NODE\n            value: my_app@$(POD_IP)\n```","ref":"FLAMEK8sBackend.html#module-clustering"},{"type":"extras","title":"FLAMEK8sBakend","doc":"# FLAMEK8sBakend\n\nA [FLAME](https://github.com/phoenixframework/flame/tree/main) Backend for\nKubernetes. Manages pods as runners in the cluster the app is running in.\n\n[![Module Version](https://img.shields.io/hexpm/v/flame_k8s_backend.svg)](https://hex.pm/packages/flame_k8s_backend)\n[![Last Updated](https://img.shields.io/github/last-commit/mruoss/flame_k8s_backend.svg)](https://github.com/mruoss/flame_k8s_backend/commits/main)\n\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/flame_k8s_backend/)\n[![Total Download](https://img.shields.io/hexpm/dt/flame_k8s_backend.svg)](https://hex.pm/packages/flame_k8s_backend)\n[![License](https://img.shields.io/hexpm/l/flame_k8s_backend.svg)](https://github.com/mruoss/flame_k8s_backend/blob/main/LICENSE)\n\nThe current implementation is very basic and more like a proof of concept.\nMore configuration options (resources, etc.) will follow.","ref":"readme.html"},{"type":"extras","title":"Installation - FLAMEK8sBakend","doc":"```elixir\ndef deps do\n  [\n    {:flame_k8s_backend, \"~> 0.2.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - FLAMEK8sBakend","doc":"Configure the flame backend in our configuration.\n\n```elixir\n# config.exs\nif config_env() == :prod do\n  config :flame, :backend, FLAMEK8sBackend\n  config :flame, FLAMEK8sBackend, log: :debug\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Prerequisites - FLAMEK8sBakend","doc":"#","ref":"readme.html#prerequisites"},{"type":"extras","title":"Env Variables - FLAMEK8sBakend","doc":"In order for the runners to be able to join the cluster, you need to configure\na few environment variables on your pod/deployment:\n\nThe `POD_NAME` and `POD_NAMESPACE` are used by the backend to get informations\nfrom your pod and use them for the runner pods (e.g. env variables).\n\n```yaml\napiVersion: apps/v1\nkind: Deployment\nspec:\n  selector:\n    matchLabels:\n      app: myapp\n  template:\n    spec:\n      containers:\n        - env:\n            - name: POD_NAME\n              valueFrom:\n                fieldRef:\n                  apiVersion: v1\n                  fieldPath: metadata.name\n            - name: POD_NAMESPACE\n              valueFrom:\n                fieldRef:\n                  apiVersion: v1\n                  fieldPath: metadata.namespace\n```\n\n#","ref":"readme.html#env-variables"},{"type":"extras","title":"RBAC - FLAMEK8sBakend","doc":"Your application needs run as a service account with permissions to manage\npods:\n\n```yaml\n---\napiVersion: v1\nkind: ServiceAccount\nmetadata:\n  name: myapp\n  namespace: app-namespace\n---\napiVersion: rbac.authorization.k8s.io/v1\nkind: Role\nmetadata:\n  namespace: app-namespace\n  name: pod-mgr\nrules:\n  - apiGroups: [\"\"]\n    resources: [\"pods\"]\n    verbs: [\"create\", \"get\", \"list\", \"delete\", \"patch\"]\n---\napiVersion: rbac.authorization.k8s.io/v1\nkind: RoleBinding\nmetadata:\n  name: myapp-pod-mgr\n  namespace: app-namespace\nsubjects:\n  - kind: ServiceAccount\n    name: myapp\n    namespace: app-namespace\nroleRef:\n  kind: Role\n  name: pod-mgr\n  apiGroup: rbac.authorization.k8s.io\n---\napiVersion: apps/v1\nkind: Deployment\nspec:\n  template:\n    spec:\n      serviceAccountName: my-app\n```\n\n#","ref":"readme.html#rbac"},{"type":"extras","title":"Clustering - FLAMEK8sBakend","doc":"Your application needs to be able to form a cluster with your runners. Define\n`POD_IP`, `RELEASE_DISTRIBUTION` and `RELEASE_NODE` environment variables on\nyour pods as follows:\n\n```yaml\napiVersion: apps/v1\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - env:\n            - name: POD_IP\n              valueFrom:\n                fieldRef:\n                  apiVersion: v1\n                  fieldPath: status.podIP\n            - name: RELEASE_DISTRIBUTION\n              value: name\n            - name: RELEASE_NODE\n              value: my_app@$(POD_IP)\n```","ref":"readme.html#clustering"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"<!-- #","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added | Changed | Deprecated | Removed | Fixed | Security --> - Changelog","doc":"## [0.2.1] - 2023-12-11\n\n#","ref":"changelog.html#added-changed-deprecated-removed-fixed-security"},{"type":"extras","title":"Changed - Changelog","doc":"- ENV var `DRAGONFLY_PARENT` was renamed to `FLAME_PARENT` in commit [9c2e65cc](https://github.com/phoenixframework/flame/commit/9c2e65ccd2c55514a473ad6ed986326576687064)\n\n## [0.2.0] - 2023-12-10\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Replace `k8s` lib with a lightweight Kubernetes client implementation.\n\n## [0.1.0] - 2023-12-09\n\n- Very early stage implementation of a Kubernetes backend.","ref":"changelog.html#changed"}],"content_type":"text/markdown"}